@@ -20,6 +20,8 @@
 #ifndef __RISTRETTO_APP_MENU_ITEM_H__
 #define __RISTRETTO_APP_MENU_ITEM_H__
 
+#include <gtk/gtk.h>
+
 G_BEGIN_DECLS
 
 #define RSTTO_TYPE_APP_MENU_ITEM rstto_app_menu_item_get_type()
@@ -59,7 +61,7 @@ struct _RsttoAppMenuItemClass
     GtkImageMenuItemClass  parent_class;
 };
 
-GType       rstto_app_menu_item_get_type();
+GType       rstto_app_menu_item_get_type (void);
 GtkWidget  *rstto_app_menu_item_new (GAppInfo *app_info, GFile *file);
 
 G_END_DECLS
