@@ -21,12 +21,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-
-#include <glib.h>
-#include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
 
