@@ -1,24 +1,29 @@
 /*
- *  Copyright (c) Stephan Arts 2009-2010 <stephan@xfce.org>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  Copyright (c) Stephan Arts 2006-2012 <stephan@xfce.org>
  *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License
+ *  as published by the Free Software Foundation; either version 2
+ *  of the License, or (at your option) any later version.
+ * 
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
- *
+ *  GNU General Public License for more details.
+ * 
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 #ifndef __RISTRETTO_IMAGE_LIST_H__
 #define __RISTRETTO_IMAGE_LIST_H__
 
+#include <gtk/gtk.h>
+
+#include "file.h"
+
 G_BEGIN_DECLS
 
 #define RSTTO_TYPE_IMAGE_LIST rstto_image_list_get_type()
@@ -92,11 +97,21 @@ struct _RsttoImageListIterClass
 };
 
 
-GType           rstto_image_list_get_type ();
-RsttoImageList *rstto_image_list_new ();
+GType
+rstto_image_list_get_type (void);
 
-gint     rstto_image_list_get_n_images (RsttoImageList *image_list);
-gboolean rstto_image_list_add_file (RsttoImageList *image_list, RsttoFile *file, GError **);
+RsttoImageList *
+rstto_image_list_new (void);
+
+gint
+rstto_image_list_get_n_images (
+        RsttoImageList *image_list);
+
+gboolean
+rstto_image_list_add_file (
+        RsttoImageList *image_list,
+        RsttoFile *file,
+        GError **);
 
 gboolean
 rstto_image_list_set_directory (
@@ -104,47 +119,81 @@ rstto_image_list_set_directory (
         GFile *dir,
         GError **);
 
+gboolean
+rstto_image_list_is_busy (
+        RsttoImageList *list );
 
-GCompareFunc rstto_image_list_get_compare_func (RsttoImageList *image_list);
-void         rstto_image_list_set_compare_func (RsttoImageList *image_list, GCompareFunc func);
+
+GCompareFunc
+rstto_image_list_get_compare_func (
+        RsttoImageList *image_list);
+void
+rstto_image_list_set_compare_func (
+        RsttoImageList *image_list,
+        GCompareFunc func);
 
 /** Built-in Sorting Functions */
 void
-rstto_image_list_set_sort_by_name (RsttoImageList *image_list);
+rstto_image_list_set_sort_by_name (
+        RsttoImageList *image_list);
+
 void
-rstto_image_list_set_sort_by_date (RsttoImageList *image_list);
+rstto_image_list_set_sort_by_type (
+        RsttoImageList *image_list);
+
+void
+rstto_image_list_set_sort_by_date (
+        RsttoImageList *image_list);
 
 RsttoImageListIter *
 rstto_image_list_get_iter (RsttoImageList *image_list);
 
 /** Iter functions */
 GType
-rstto_image_list_iter_get_type ();
+rstto_image_list_iter_get_type (void);
 
 RsttoFile *
-rstto_image_list_iter_get_file ( RsttoImageListIter *iter );
+rstto_image_list_iter_get_file (
+        RsttoImageListIter *iter );
 
 gboolean
-rstto_image_list_iter_previous (RsttoImageListIter *iter);
-gboolean
-rstto_image_list_iter_next (RsttoImageListIter *iter);
+rstto_image_list_iter_previous (
+        RsttoImageListIter *iter);
 
 gboolean
-rstto_image_list_iter_has_previous (RsttoImageListIter *iter);
+rstto_image_list_iter_next (
+        RsttoImageListIter *iter);
+
 gboolean
-rstto_image_list_iter_has_next (RsttoImageListIter *iter);
+rstto_image_list_iter_has_previous (
+        RsttoImageListIter *iter);
+
+gboolean
+rstto_image_list_iter_has_next (
+        RsttoImageListIter *iter);
 
 gint
-rstto_image_list_iter_get_position (RsttoImageListIter *iter);
-void
-rstto_image_list_iter_set_position (RsttoImageListIter *iter, gint pos);
+rstto_image_list_iter_get_position (
+        RsttoImageListIter *iter);
 
 void
-rstto_image_list_remove_file (RsttoImageList *image_list, RsttoFile *file);
+rstto_image_list_iter_set_position (
+        RsttoImageListIter *iter,
+        gint pos);
+
+void
+rstto_image_list_remove_file (
+        RsttoImageList *image_list,
+        RsttoFile *file);
+
 gboolean
-rstto_image_list_iter_find_file (RsttoImageListIter *iter, RsttoFile *file);
+rstto_image_list_iter_find_file (
+        RsttoImageListIter *iter,
+        RsttoFile *file);
 
-RsttoImageListIter *rstto_image_list_iter_clone (RsttoImageListIter *iter);
+RsttoImageListIter *
+rstto_image_list_iter_clone (
+        RsttoImageListIter *iter);
 
 gboolean
 rstto_image_list_iter_get_sticky (
