@@ -18,7 +18,6 @@
  */
 
 #include <config.h>
-#include <gtk/gtk.h>
 #include <string.h>
 #include <gio/gio.h>
 #include <libxfce4ui/libxfce4ui.h>
@@ -27,8 +26,6 @@
 #include <math.h>
 
 #include "util.h"
-
-#include "file.h"
 #include "image_viewer.h"
 #include "settings.h"
 #include "marshal.h"
@@ -744,11 +741,15 @@ set_scale (RsttoImageViewer *viewer, gdouble scale )
     {
         case RSTTO_IMAGE_ORIENT_90:
         case RSTTO_IMAGE_ORIENT_270:
+        case RSTTO_IMAGE_ORIENT_FLIP_TRANSVERSE:
+        case RSTTO_IMAGE_ORIENT_FLIP_TRANSPOSE:
             v_scale = (gdouble)(allocation.width) / (gdouble)viewer->priv->image_height;
             h_scale = (gdouble)(allocation.height) / (gdouble)viewer->priv->image_width;
             break;
         case RSTTO_IMAGE_ORIENT_NONE:
         case RSTTO_IMAGE_ORIENT_180:
+        case RSTTO_IMAGE_ORIENT_FLIP_HORIZONTAL:
+        case RSTTO_IMAGE_ORIENT_FLIP_VERTICAL:
         default:
             v_scale = (gdouble)(allocation.width) / (gdouble)viewer->priv->image_width;
             h_scale = (gdouble)(allocation.height) / (gdouble)viewer->priv->image_height;
@@ -993,6 +994,8 @@ correct_adjustments (RsttoImageViewer *viewer)
     {
         case RSTTO_IMAGE_ORIENT_NONE:
         case RSTTO_IMAGE_ORIENT_180:
+        case RSTTO_IMAGE_ORIENT_FLIP_HORIZONTAL:
+        case RSTTO_IMAGE_ORIENT_FLIP_VERTICAL:
         default:
             gtk_adjustment_set_upper (
                     viewer->hadjustment,
@@ -1030,6 +1033,8 @@ correct_adjustments (RsttoImageViewer *viewer)
             break;
         case RSTTO_IMAGE_ORIENT_90:
         case RSTTO_IMAGE_ORIENT_270:
+        case RSTTO_IMAGE_ORIENT_FLIP_TRANSPOSE:
+        case RSTTO_IMAGE_ORIENT_FLIP_TRANSVERSE:
             gtk_adjustment_set_upper (
                     viewer->hadjustment,
                     floor(image_height * scale));
@@ -1176,6 +1181,7 @@ paint_image (GtkWidget *widget, cairo_t *ctx)
     gint block_height = 10;
     gdouble bg_scale = 1.0;
     GtkAllocation allocation;
+    cairo_matrix_t transform_matrix;
 
     gtk_widget_get_allocation (widget, &allocation);
 
@@ -1185,6 +1191,8 @@ paint_image (GtkWidget *widget, cairo_t *ctx)
         {
             case RSTTO_IMAGE_ORIENT_90:
             case RSTTO_IMAGE_ORIENT_270:
+            case RSTTO_IMAGE_ORIENT_FLIP_TRANSVERSE:
+            case RSTTO_IMAGE_ORIENT_FLIP_TRANSPOSE:
                 viewer->priv->rendering.x_offset = ((gdouble)allocation.width - (
                             (gdouble)viewer->priv->image_height * 
                                 viewer->priv->scale) ) / 2.0;
@@ -1198,6 +1206,8 @@ paint_image (GtkWidget *widget, cairo_t *ctx)
                 break;
             case RSTTO_IMAGE_ORIENT_NONE:
             case RSTTO_IMAGE_ORIENT_180:
+            case RSTTO_IMAGE_ORIENT_FLIP_HORIZONTAL:
+            case RSTTO_IMAGE_ORIENT_FLIP_VERTICAL:
             default:
                 viewer->priv->rendering.x_offset = ((gdouble)allocation.width - (
                             (gdouble)viewer->priv->image_width * 
@@ -1275,9 +1285,74 @@ paint_image (GtkWidget *widget, cairo_t *ctx)
 /* END PAINT CHECKERED BACKGROUND */
         cairo_restore (ctx);
 
-        /* TODO: make this work for all rotations */
         switch (viewer->priv->orientation)
         {
+            case RSTTO_IMAGE_ORIENT_FLIP_HORIZONTAL:
+                cairo_translate (
+                        ctx,
+                        0.0 - floor(gtk_adjustment_get_value (viewer->hadjustment)),
+                        0.0 - floor(gtk_adjustment_get_value (viewer->vadjustment)));
+                cairo_translate (
+                        ctx,
+                        viewer->priv->image_width * viewer->priv->scale,
+                        0.0);
+                cairo_translate (
+                        ctx,
+                        x_offset,
+                        y_offset);
+                cairo_matrix_init_identity(&transform_matrix);
+                transform_matrix.xx = -1.0;
+                cairo_transform(ctx, &transform_matrix);
+                break;
+            case RSTTO_IMAGE_ORIENT_FLIP_VERTICAL:
+                cairo_translate (
+                        ctx,
+                        0.0 - floor(gtk_adjustment_get_value (viewer->hadjustment)),
+                        0.0 - floor(gtk_adjustment_get_value (viewer->vadjustment)));
+                cairo_translate (
+                        ctx,
+                        0.0,
+                        viewer->priv->image_height * viewer->priv->scale);
+                cairo_translate (
+                        ctx,
+                        x_offset,
+                        y_offset);
+                cairo_matrix_init_identity(&transform_matrix);
+                transform_matrix.yy = -1.0;
+                cairo_transform(ctx, &transform_matrix);
+                break;
+            case RSTTO_IMAGE_ORIENT_FLIP_TRANSPOSE:
+                cairo_rotate ( ctx, M_PI*1.5);
+                cairo_translate (
+                        ctx,
+                        floor(gtk_adjustment_get_value (viewer->vadjustment)),
+                        floor(0.0 - gtk_adjustment_get_value (viewer->hadjustment)));
+                cairo_translate (
+                        ctx,
+                        -1.0 * y_offset,
+                        x_offset);
+                cairo_matrix_init_identity(&transform_matrix);
+                transform_matrix.xx = -1.0;
+                cairo_transform(ctx, &transform_matrix);
+                break;
+            case RSTTO_IMAGE_ORIENT_FLIP_TRANSVERSE:
+                cairo_rotate ( ctx, M_PI*0.5);
+                cairo_translate (
+                        ctx,
+                        floor(0.0 - gtk_adjustment_get_value (viewer->vadjustment)),
+                        floor(gtk_adjustment_get_value (viewer->hadjustment)));
+                cairo_translate (
+                        ctx,
+                        viewer->priv->image_width * viewer->priv->scale,
+                        -1.0 * viewer->priv->image_height * viewer->priv->scale);
+                cairo_translate (
+                        ctx,
+                        y_offset,
+                        -1.0 * x_offset);
+                cairo_matrix_init_identity(&transform_matrix);
+                transform_matrix.xx = -1.0;
+                cairo_transform(ctx, &transform_matrix);
+                break;
             case RSTTO_IMAGE_ORIENT_90:
                 cairo_rotate (
                         ctx,
@@ -2280,11 +2355,15 @@ rstto_scroll_event (GtkWidget *widget, GdkEventScroll *event)
                 {
                     case RSTTO_IMAGE_ORIENT_90:
                     case RSTTO_IMAGE_ORIENT_270:
+                    case RSTTO_IMAGE_ORIENT_FLIP_TRANSPOSE:
+                    case RSTTO_IMAGE_ORIENT_FLIP_TRANSVERSE:
                         v_scale = (gdouble)(allocation.width) / (gdouble)viewer->priv->image_height;
                         h_scale = (gdouble)(allocation.height) / (gdouble)viewer->priv->image_width;
                         break;
                     case RSTTO_IMAGE_ORIENT_NONE:
                     case RSTTO_IMAGE_ORIENT_180:
+                    case RSTTO_IMAGE_ORIENT_FLIP_HORIZONTAL:
+                    case RSTTO_IMAGE_ORIENT_FLIP_VERTICAL:
                     default:
                         v_scale = (gdouble)(allocation.width) / (gdouble)viewer->priv->image_width;
                         h_scale = (gdouble)(allocation.height) / (gdouble)viewer->priv->image_height;
