@@ -20,6 +20,10 @@
 #ifndef __RISTRETTO_MAIN_WINDOW_H__
 #define __RISTRETTO_MAIN_WINDOW_H__
 
+#include <gtk/gtk.h>
+
+#include "image_list.h"
+
 G_BEGIN_DECLS
 
 #define RSTTO_TYPE_MAIN_WINDOW rstto_main_window_get_type()
@@ -66,7 +70,8 @@ typedef enum {
 } RsttoDesktop;
 
 
-GType      rstto_main_window_get_type();
+GType
+rstto_main_window_get_type (void);
 
 GtkWidget *
 rstto_main_window_new (RsttoImageList *, gboolean);
