@@ -18,8 +18,6 @@
  */
 
 #include <config.h>
-#include <gtk/gtk.h>
-#include <libxfce4ui/libxfce4ui.h>
 #include <libxfce4util/libxfce4util.h>
 
 #include "settings.h"
@@ -292,12 +290,18 @@ static void
 rstto_privacy_dialog_dispose (GObject *object)
 {
     RsttoPrivacyDialog *dialog = RSTTO_PRIVACY_DIALOG (object);
-    if (dialog->priv->settings)
+    if (dialog->priv)
     {
-        g_object_unref (dialog->priv->settings);
-        dialog->priv->settings = NULL;
+        if (dialog->priv->settings)
+        {
+            g_object_unref (dialog->priv->settings);
+            dialog->priv->settings = NULL;
+        }
+
+        g_free (dialog->priv);
+        dialog->priv = NULL;
     }
-    
+
     G_OBJECT_CLASS(parent_class)->dispose(object);
 }
 
