@@ -20,6 +20,8 @@
 #ifndef __RISTRETTO_PRIVACY_DIALOG_H__
 #define __RISTRETTO_PRIVACY_DIALOG_H__
 
+#include <libxfce4ui/libxfce4ui.h>
+
 G_BEGIN_DECLS
 
 #define RSTTO_TYPE_PRIVACY_DIALOG rstto_privacy_dialog_get_type()
@@ -60,7 +62,7 @@ struct _RsttoPrivacyDialogClass
 };
 
 GType
-rstto_privacy_dialog_get_type();
+rstto_privacy_dialog_get_type (void);
 
 GtkWidget *
 rstto_privacy_dialog_new (
