@@ -20,7 +20,6 @@
 #include <config.h>
 
 #include <glib.h>
-#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <xfconf/xfconf.h>
 #include <libxfce4util/libxfce4util.h>
@@ -642,6 +641,12 @@ rstto_settings_dispose (GObject *object)
             settings->priv->navigationbar_position = NULL;
         }
 
+        if (settings->priv->desktop_type)
+        {
+            g_free (settings->priv->desktop_type);
+            settings->priv->desktop_type = NULL;
+        }
+
         if (settings->priv->bgcolor)
         {
             g_free (settings->priv->bgcolor);
